@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "8764bdcbc27624a9ef69d9f544ba94d19e725fb5",
-  "branchName": "release-client-5.x",
-  "buildTime": "2024-04-11 14:10:05 GMT",
-  "buildVersion": "1.0.194",
+  "commitId": "2d1642ea4e08d76f16ed47e0e00f4ea7e155e074",
+  "branchName": "release-client-6.0.x",
+  "buildTime": "2024-05-23 08:08:24 GMT",
+  "buildVersion": "1.0.396",
   "css": [
     "@zoom/client-calendar-dev/static/css/chunk-vendors.974eca6e.css",
-    "@zoom/client-calendar-dev/static/css/app.ff64ca48.css"
+    "@zoom/client-calendar-dev/static/css/app.accf4c46.css"
   ],
   "js": [
-    "@zoom/client-calendar-dev/static/js/chunk-vendors.1bc7ace7.js",
-    "@zoom/client-calendar-dev/static/js/app.708cb2a3.js"
+    "@zoom/client-calendar-dev/static/js/chunk-vendors.022f4ebd.js",
+    "@zoom/client-calendar-dev/static/js/app.777c55fb.js"
   ],
   "key": "@zoom/client-calendar-dev"
 };
